EasyDict — Fleras

Skip to main content
`Ctrl`+`K`

# EasyDict

class fleras.EasyDict(d=None, **kwargs)

  Bases: `dict`

  dict() -> new empty dictionary dict(mapping) -> new dictionary initialized from a mapping object’s

  > (key, value) pairs

  dict(iterable) -> new dictionary initialized as if via:

    d = {} for k, v in iterable:

    > d[k] = v

  dict(**kwargs) -> new dictionary initialized with the name=value pairs

    in the keyword argument list. For example: dict(one=1, two=2)

## Attributes

`__setitem__` | Set self[key] to value.

## Methods

`__setattr__`(name, value) | Implement setattr(self, name, value).
`update`([e]) | D.update([E, ]**F) -> None. Update D from dict/iterable E and F.
`pop`(k[, d]) | D.pop(k[,d]) -> v, remove specified key and return the corresponding value.